@@ -3,7 +3,6 @@
  *
  * Authors:
  *     Conor Curran <conor.curran@canonical.com>
- *     Cody Russell <crussell@canonical.com>
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -23,6 +22,9 @@
 
 #include <glib.h>
 #include <glib-object.h>
+#include <libdbusmenu-glib/menuitem.h>
+#include "common-defs.h"
+
 
 G_BEGIN_DECLS
 
@@ -48,12 +50,16 @@ struct _SoundServiceDbus {
 struct _SoundServiceDbusClass {
   GObjectClass parent_class;
 };
+
 GType sound_service_dbus_get_type  (void) G_GNUC_CONST;
 
-// Utility methods to get the SIGNAL messages across into the sound-service-dbus
-void sound_service_dbus_sink_input_while_muted (SoundServiceDbus* obj, gboolean block_value);
-void sound_service_dbus_update_sink_mute(SoundServiceDbus* obj, gboolean sink_mute);
-void sound_service_dbus_update_sink_availability(SoundServiceDbus* obj, gboolean sink_availibity);
+DbusmenuMenuitem* sound_service_dbus_create_root_item (SoundServiceDbus* self);
+void sound_service_dbus_update_sound_state (SoundServiceDbus* self, SoundState new_state);
+void sound_service_dbus_build_sound_menu ( SoundServiceDbus* self,
+                                           DbusmenuMenuitem* mute_item,
+                                           DbusmenuMenuitem* slider_item,
+                                           DbusmenuMenuitem* voip_input_menu_item);
+
 
 G_END_DECLS
 
