@@ -1,5 +1,4 @@
 /*
-This service primarily controls PulseAudio and is driven by the sound indicator menu on the panel.
 Copyright 2010 Canonical Ltd.
 
 Authors:
@@ -19,10 +18,12 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include "sound-service.h"
-#include "dbus-menu-manager.h"
-#include "pulse-manager.h"
+#include "pulseaudio-mgr.h"
+#include "sound-service-dbus.h"
 #include "music-player-bridge.h"
 
+#include <locale.h>
+
 static GMainLoop *mainloop = NULL;
 
 /**********************************************************************************************************************/
@@ -40,7 +41,6 @@ service_shutdown (IndicatorService *service, gpointer user_data)
 {
   if (mainloop != NULL) {
     g_debug("Service shutdown !");
-    //TODO: uncomment for release !!
     close_pulse_activites();
     g_main_loop_quit(mainloop);
   }
@@ -53,11 +53,11 @@ main:
 int
 main (int argc, char ** argv)
 {
+  
   g_type_init();
-
-  setlocale (LC_ALL, "");
-  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
   textdomain (GETTEXT_PACKAGE);
+  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  setlocale (LC_ALL, "");
 
   IndicatorService *service = indicator_service_new_version(INDICATOR_SOUND_DBUS_NAME,
                               INDICATOR_SOUND_DBUS_VERSION);
@@ -65,7 +65,9 @@ main (int argc, char ** argv)
                    INDICATOR_SERVICE_SIGNAL_SHUTDOWN,
                    G_CALLBACK(service_shutdown), NULL);
 
-  DbusmenuMenuitem* root_menuitem = dbus_menu_manager_setup();
+  SoundServiceDbus* sound_service = g_object_new(SOUND_SERVICE_DBUS_TYPE, NULL);
+  
+  DbusmenuMenuitem* root_menuitem = sound_service_dbus_create_root_item(sound_service);
   MusicPlayerBridge* server = music_player_bridge_new();
   music_player_bridge_set_root_menu_item(server, root_menuitem);
 
